<?php

namespace Drupal\slicarousel\Plugin\views\style;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;

/**
 * Style plugin to render each item into  Sli carousel.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "slicarousel",
 *   title = @Translation("slicarousel"),
 *   help = @Translation("Displays rows as SliCarousel."),
 *   theme = "slicarousel_views",
 *   display_types = {"normal"}
 * )
 */
class SliCarousel extends StylePluginBase {

  /**
   * Does the style plugin allows to use style plugins.
   *
   * @var bool
   */
  protected $usesRowPlugin = TRUE;

  /**
   * Does the style plugin support custom css class for the rows.
   *
   * @var bool
   */
  protected $usesRowClass = TRUE;

  /**
   * Set default options.
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $settings = _slicarousel_default_settings();
    foreach ($settings as $k => $v) {
      $options[$k] = ['default' => $v];
    }
    return $options;
  }

  /**
   * Render the given style.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    $form['autoplay'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Autoplay'),
      '#default_value' => $this->options['autoplay'],
    ];
    // Navigation.
    $form['arrows'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('arrows'),
      '#default_value' => $this->options['arrows'],
      '#description' => $this->t('Display "next" and "prev" buttons.'),
    ];
    $form['dot_nav'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('dot nav'),
      '#description' => $this->t('dot navigation.'),
      '#default_value' => $this->options['dot_nav'],
    ];
    $form['full_width'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('full width'),
      '#description' => $this->t('full_width'),
      '#default_value' => $this->options['full_width'],
    ];
    // rewindNav.
    $form['nbr_slides'] = [
      '#type' => 'number',
      '#title' => $this->t('nbr_slides'),
      '#default_value' => $this->options['nbr_slides'],
      '#description' => $this->t('number of Slides to first item.'),
    ];
    $form['speed'] = [
      '#type' => 'number',
      '#title' => $this->t('Transition Speed'),
      '#default_value' => $this->options['speed'],
      '#description' => $this->t('Transition speed in milliseconds.'),
    ];
    $form['delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Delay'),
      '#default_value' => $this->options['delay'],
      '#description' => $this->t('Delay.'),
    ];

  }

}
